
import datetime
import uuid

from nsj_rest_lib.decorator.dto import DTO
from nsj_rest_lib.descriptor.dto_field import DTOField
from nsj_rest_lib.descriptor.dto_field_validators import DTOFieldValidators
from nsj_rest_lib.dto.dto_base import DTOBase



# Configuracoes execucao
from nsj_integracao_api_entidades.config import (tenant_is_partition_data)

@DTO()
class DfLinhaDTO(DTOBase):
    # Atributos da entidade
    id: uuid.UUID = DTOField(
      pk=True,
      entity_field='df_linha',
      resume=True,
      not_null=True,
      strip=True,
      min=36,
      max=36,
      validator=DTOFieldValidators().validate_uuid,)
    tenant: int = DTOField(
      partition_data=tenant_is_partition_data,
      resume=True,
      not_null=True,)
    df_linha_origem: uuid.UUID = DTOField(
      strip=True,
      min=36,
      max=36,
      validator=DTOFieldValidators().validate_uuid,)
    id_item: uuid.UUID = DTOField(
      strip=True,
      min=36,
      max=36,
      validator=DTOFieldValidators().validate_uuid,)
    id_cfop: uuid.UUID = DTOField(
      strip=True,
      min=36,
      max=36,
      validator=DTOFieldValidators().validate_uuid,)
    id_docfis: uuid.UUID = DTOField(
      not_null=True,
      strip=True,
      min=36,
      max=36,
      validator=DTOFieldValidators().validate_uuid,)
    id_docfis_origem: uuid.UUID = DTOField(
      strip=True,
      min=36,
      max=36,
      validator=DTOFieldValidators().validate_uuid,)
    produto: uuid.UUID = DTOField(
      strip=True,
      min=36,
      max=36,
      validator=DTOFieldValidators().validate_uuid,)
    tipolinha: int = DTOField(
      not_null=True,)
    marcado: bool = DTOField()
    quantidadecomercial: float = DTOField()
    valorunitariocomercial: float = DTOField()
    valortotal: float = DTOField()
    valordesconto: float = DTOField()
    codigobarratributavel: str = DTOField()
    quantidadetributavel: float = DTOField()
    valorunitariotributacao: float = DTOField()
    valorfrete: float = DTOField()
    valorseguro: float = DTOField()
    valoroutrasdespesas: float = DTOField()
    extipi: float = DTOField()
    razaoconversao: float = DTOField()
    alteratotalnfe: bool = DTOField()
    ordem: int = DTOField(
      not_null=True,)
    id_localdeestoque: uuid.UUID = DTOField(
      strip=True,
      min=36,
      max=36,
      validator=DTOFieldValidators().validate_uuid,)
    localdeestoquedescricao: str = DTOField()
    codigoitemfornecedor: str = DTOField()
    lastupdate: datetime.datetime = DTOField()
    id_unidade_comercial: uuid.UUID = DTOField(
      strip=True,
      min=36,
      max=36,
      validator=DTOFieldValidators().validate_uuid,)
    unidade_comercial: str = DTOField()
    id_unidade_tributada: uuid.UUID = DTOField(
      strip=True,
      min=36,
      max=36,
      validator=DTOFieldValidators().validate_uuid,)
    unidade_tributada: str = DTOField()
    valorbasemarkup: float = DTOField()
    formulabasemarkup: str = DTOField()
    observacao: str = DTOField()
    id_linha_docfis_origem: uuid.UUID = DTOField(
      strip=True,
      min=36,
      max=36,
      validator=DTOFieldValidators().validate_uuid,)
    ipienquadramento_id: uuid.UUID = DTOField(
      strip=True,
      min=36,
      max=36,
      validator=DTOFieldValidators().validate_uuid,)
    ipienquadramento_codigo: str = DTOField()
    ibptbase: float = DTOField()
    ibptaliquotafederal: float = DTOField()
    ibptaliquotaestadual: float = DTOField()
    ibptaliquotamunicipal: float = DTOField()
    ibptvalor: float = DTOField()
    id_di: uuid.UUID = DTOField(
      strip=True,
      min=36,
      max=36,
      validator=DTOFieldValidators().validate_uuid,)
    id_adicao: uuid.UUID = DTOField(
      strip=True,
      min=36,
      max=36,
      validator=DTOFieldValidators().validate_uuid,)
    id_adicao_item: uuid.UUID = DTOField(
      strip=True,
      min=36,
      max=36,
      validator=DTOFieldValidators().validate_uuid,)
    tipo_documento_origem: int = DTOField(
      not_null=True,)
    di_numero: str = DTOField()
    di_registro: datetime.datetime = DTOField()
    di_adicao_numero: str = DTOField()
    cest: str = DTOField()
    id_comentario: uuid.UUID = DTOField(
      strip=True,
      min=36,
      max=36,
      validator=DTOFieldValidators().validate_uuid,)
    comentario: str = DTOField()
    id_composicao_instancia: uuid.UUID = DTOField(
      strip=True,
      min=36,
      max=36,
      validator=DTOFieldValidators().validate_uuid,)
    id_instancia: uuid.UUID = DTOField(
      strip=True,
      min=36,
      max=36,
      validator=DTOFieldValidators().validate_uuid,)
    situacaogerencial: int = DTOField()
    codigoitemdocfis: str = DTOField()
    descricaoitemdocfis: str = DTOField()
    custo: float = DTOField()
    dataprevisaoentrega: datetime.datetime = DTOField()
    fci: str = DTOField()
    numeropedidocompra: str = DTOField()
    itempedidocompra: str = DTOField()
    comb_cprodanp: str = DTOField()
    comb_ufcons: str = DTOField()
    peso_bruto: float = DTOField()
    peso_liquido: float = DTOField()
    especie: str = DTOField()
    marca: str = DTOField()
    aprovado: bool = DTOField()
    ratfrete: float = DTOField()
    ratseguro: float = DTOField()
    ratdespaduaneira: float = DTOField()
    ratdespacessorias: float = DTOField()
    ratsiscomex: float = DTOField()
    rataframm: float = DTOField()
    ratoutrasdesp: float = DTOField()
    custo_dif_cofins: float = DTOField()
    cfop_original: str = DTOField()
    codigo_beneficio_fiscal: str = DTOField()
    destinacao: int = DTOField()
    fabricante: str = DTOField()
    id_beneficio_fiscal: uuid.UUID = DTOField(
      strip=True,
      min=36,
      max=36,
      validator=DTOFieldValidators().validate_uuid,)
    id_cfop_previsto: uuid.UUID = DTOField(
      strip=True,
      min=36,
      max=36,
      validator=DTOFieldValidators().validate_uuid,)
    id_tabeladepreco: uuid.UUID = DTOField(
      strip=True,
      min=36,
      max=36,
      validator=DTOFieldValidators().validate_uuid,)
    idorigemlinha: uuid.UUID = DTOField(
      strip=True,
      min=36,
      max=36,
      validator=DTOFieldValidators().validate_uuid,)
    indicador_escala_relevante: int = DTOField()
    observacao_automatico: str = DTOField()
    observacao_manual: str = DTOField()
    volume_razao: float = DTOField(
      not_null=True,)
    qtd_entregue_romaneio: float = DTOField()
    percentualcomissao: float = DTOField()
    valorcomissao: float = DTOField()

